@@ -11,7 +11,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include <cc++/network.h>
@@ -21,20 +21,18 @@ int main(int argc, char* argv[])
 {
   std::vector<ost::NetworkDeviceInfo> devs;
 
-  if(!enumNetworkDevices(devs))
-    {
-      std::cerr << "Could not get list of network devices!" << std::endl;
-      return -1;
-    }
+  if(!enumNetworkDevices(devs)) {
+	  std::cerr << "Could not get list of network devices!" << std::endl;
+	  return -1;
+	}
 
   std::cout << "Available network devices:" << std::endl;
   std::vector<ost::NetworkDeviceInfo>::const_iterator i = devs.begin();
-  while(i != devs.end())
-    {
-      std::cout << (*i).name() << " address: " << (*i).address()
+  while(i != devs.end()) {
+	  std::cout << (*i).name() << " address: " << (*i).address()
 		<< ", brdcast: " << (*i).broadcast()
 		<< ", netmask: " << (*i).netmask()
 		<< ", mtu: " << (*i).mtu() << std::endl;
-      ++i;
-    }
+	  ++i;
+	}
 }
