@@ -1,4 +1,5 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -262,15 +263,21 @@ public:
 	/**
 	 * Constructs a Persistence::Engine with the specified stream in
 	 * the given mode. The stream must be initialised properly prior
-	 * to this call or problems will ensue.
+	 * to this call or problems will ensue. If built using zlib compress
+         * can be used to enable compression
 	 */
-	Engine(std::iostream& stream, EngineMode mode) THROWS (PersistException);
+	Engine(std::iostream& stream, EngineMode mode, bool compress=true) THROWS (PersistException);
 
 	/**
 	 * This Flushes the buffers and closes the Persistence::Engine
 	 * this must happen before the underlying stream is shut down
 	 */
-  void sync();
+	void sync();
+	
+	/**
+	 * This says there are more objects to deserialize
+	 */
+	bool more();
 
 	virtual ~Engine();
 
@@ -289,7 +296,7 @@ public:
 	void write(const BaseObject *object) THROWS (PersistException);
 
 	// writes supported primitive types
-  // shortcut, to make the following more readable
+	// shortcut, to make the following more readable
 #define CCXX_ENGINEWRITE_REF(valref) writeBinary((const uint8*)&valref,sizeof(valref))
 	void write(int8 i)   THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
 	void write(uint8 i)  THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
@@ -319,7 +326,7 @@ public:
 	 */
 	void read(BaseObject &object) THROWS (PersistException);
 
-  /**
+	/**
 	 * reads a BaseObject into a pointer allocating memory for the object if necessary.
 	 */
 	void read(BaseObject *&object) THROWS (PersistException);
@@ -384,6 +391,7 @@ private:
 	ClassMap myClassMap;
 
 	// Compression support
+	bool use_compression; // valid onlry if NO_COMPRESSION is false
 #ifndef NO_COMPRESSION
 	z_stream myZStream;
 	uint8* myCompressedDataBuffer;
