@@ -464,7 +464,7 @@ protected:
 	 * @param buf pointer to byte allocation.
 	 * @param len maximum length to write.
 	 * @param t timeout for pending data in milliseconds.
-	 * @return number of bytes actually read.
+	 * @return number of bytes actually written.
 	 */
 	virtual ssize_t writeData(const void* buf,size_t len,timeout_t t=0);
 
@@ -500,13 +500,13 @@ public:
 	 * @param port ptr to port number of sender.
 	 * @return host address, test with "isInetAddress()".
 	 */
-	IPV4Host getIPV4Sender(tpport_t *port = NULL) const;
+	virtual IPV4Host getIPV4Sender(tpport_t *port = NULL) const;
 
 	inline IPV4Host getSender(tpport_t *port = NULL) const
 		{return getIPV4Sender(port);}
 
 #ifdef	CCXX_IPV6
-	IPV6Host getIPV6Sender(tpport_t *port = NULL) const;
+	virtual IPV6Host getIPV6Sender(tpport_t *port = NULL) const;
 #endif
 
 	/**
@@ -695,7 +695,7 @@ public:
  * DCCP sockets are used for stream based connected sessions between two
  * sockets.  Both error recovery and flow control operate transparently
  * for a DCCP socket connection.  The DCCP socket base class is used both
- * for client connections and to bind a DCCP "server" for accepting DCCP 
+ * for client connections and to bind a DCCP "server" for accepting DCCP
  * streams.
  *
  * An implicit and unique DCCPSocket object exists in Common C++ to represent
@@ -727,7 +727,7 @@ class __EXPORT DCCPSocket : public Socket
 	}	peer;
 
 	Family family;
-	
+
 public:
 	/**
 	 * A method to call in a derived DCCPSocket class that is acting
@@ -745,6 +745,12 @@ public:
 	virtual bool onAccept(const IPV6Host &ia, tpport_t port);
 #endif
 
+	virtual IPV4Host getIPV4Sender(tpport_t *port = NULL) const;
+
+#ifdef	CCXX_IPV6
+	virtual IPV6Host getIPV6Sender(tpport_t *port = NULL) const;
+#endif
+
 	/**
 	 * A DCCP "server" is created as a DCCP socket that is bound
 	 * to a hardware address and port number on the local machine
@@ -795,7 +801,22 @@ public:
 	/**
 	 * Set CCID DCCP.
 	 */
-	bool setCCID(uint8_t ccid);
+	bool setCCID(uint8 ccid);
+
+    	/**
+    	 * Get TX CCID DCCP.
+     	 */
+    	int getTxCCID();
+
+    	/**
+     	 * Get RX CCID DCCP.
+     	 */
+    	int getRxCCID();
+
+    	/**
+     	 * Return number of bytes to be read
+     	 */
+    	size_t available();
 
 	/**
 	 * Create a DCCP client connection to a DCCP socket (on
