@@ -199,11 +199,7 @@ void IPV4Cidr::set(const char *cp)
 	bitset((bit_t *)&netmask, getMask(cp));
 	setString(cbuf, sizeof(cbuf), cp);
 	
-#if defined(_MSC_VER) && _MSC_VER >= 1500
 	ep = (char *)strchr(cp, '/');
-#else
- 	ep = strchr(cp, '/');
-#endif
 
 	if(ep)
 		*ep = 0;
@@ -332,7 +328,7 @@ void IPV6Cidr::set(const char *cp)
 	memset(&netmask, 0, sizeof(netmask));
 	bitset((bit_t *)&netmask, getMask(cp));
 	setString(cbuf, sizeof(cbuf), cp);
-	ep = strchr(cp, '/');
+	ep = (char *)strchr(cp, '/');
 	if(ep)
 		*ep = 0;
 
