@@ -65,156 +65,207 @@ const uint32 MAX_BUFFER = 16384;
 
 const uint32 NullObject = 0xffffffff;
 
-Engine::Engine(std::iostream& stream, EngineMode mode) THROWS (PersistException)
-  : myUnderlyingStream(stream), myOperationalMode(mode) {
+Engine::Engine(std::iostream& stream, EngineMode mode, bool compress) THROWS (PersistException)
+  : myUnderlyingStream(stream), myOperationalMode(mode), use_compression(compress) {
   // Nothing else to initialise for now
 #ifndef NO_COMPRESSION
-  myZStream.zalloc = (alloc_func)NULL;
-  myZStream.zfree = (free_func)NULL;
-  myZStream.opaque = (voidpf)NULL;
-  myCompressedDataBuffer = new uint8[MAX_BUFFER];
-  myUncompressedDataBuffer = new uint8[MAX_BUFFER];
-  myLastUncompressedDataRead = myUncompressedDataBuffer;
-  if (myOperationalMode == modeRead) {
-	myZStream.next_in = myCompressedDataBuffer;
-	myZStream.next_out = myUncompressedDataBuffer;
-	myZStream.avail_in = 0;
-	myZStream.avail_out = MAX_BUFFER;
-	int err = inflateInit(&myZStream);
-	if (err != Z_OK) {
-	  THROW (PersistException(String("zLib didn't initialise for inflating.")));
-		}
-  }
-  else {
-	myZStream.next_in = myUncompressedDataBuffer;
-	myZStream.next_out = myCompressedDataBuffer;
-	myZStream.avail_in = 0;
-	myZStream.avail_out = MAX_BUFFER;
-	int err = deflateInit(&myZStream,9); // TODO: tweak compression level
-	if (err != Z_OK) {
-	  THROW (PersistException(String("zLib didn't initialise for deflating.")));
-		}
+  if ( use_compression )
+  {
+    myZStream.zalloc = ( alloc_func ) NULL;
+    myZStream.zfree = ( free_func ) NULL;
+    myZStream.opaque = ( voidpf ) NULL;
+    myCompressedDataBuffer = new uint8[MAX_BUFFER];
+    myUncompressedDataBuffer = new uint8[MAX_BUFFER];
+    myLastUncompressedDataRead = myUncompressedDataBuffer;
+    if ( myOperationalMode == modeRead )
+    {
+      myZStream.next_in = myCompressedDataBuffer;
+      myZStream.next_out = myUncompressedDataBuffer;
+      myZStream.avail_in = 0;
+      myZStream.avail_out = MAX_BUFFER;
+      int err = inflateInit ( &myZStream );
+      if ( err != Z_OK )
+      {
+        THROW ( PersistException ( String ( "zLib didn't initialise for inflating." ) ) );
+      }
+    }
+    else
+    {
+      myZStream.next_in = myUncompressedDataBuffer;
+      myZStream.next_out = myCompressedDataBuffer;
+      myZStream.avail_in = 0;
+      myZStream.avail_out = MAX_BUFFER;
+      int err = deflateInit ( &myZStream, 9 ); // TODO: tweak compression level
+      if ( err != Z_OK )
+      {
+        THROW ( PersistException ( String ( "zLib didn't initialise for deflating." ) ) );
+      }
+    }
   }
 #endif
 }
 
+bool Engine::more()
+{
+#ifndef NO_COMPRESSION
+  if ( use_compression && myOperationalMode == modeRead )
+    return ( myLastUncompressedDataRead < myZStream.next_out );
+#endif
+
+  return false;
+}
+
 void Engine::sync()
 {
   // Flush compression buffers etc here.
 #ifndef NO_COMPRESSION
-  if (myOperationalMode == modeRead) {
-	inflateEnd(&myZStream);
-  }
-  else {
-	int zret = Z_OK;
-	while (myZStream.avail_in > 0 || zret == Z_OK) {
-	  zret = deflate(&myZStream,Z_FINISH);
-	  if (myZStream.avail_out >= 0) {
-		myUnderlyingStream.write((char*)myCompressedDataBuffer,MAX_BUFFER - myZStream.avail_out);
-		myZStream.next_out = myCompressedDataBuffer;
-		myZStream.avail_out = MAX_BUFFER;
-	  }
-		}
-	deflateEnd(&myZStream);
+  if ( use_compression )
+  {
+    if ( myOperationalMode == modeRead )
+    {
+      inflateEnd ( &myZStream );
+    }
+    else
+    {
+      int zret = Z_OK;
+      while ( myZStream.avail_in > 0 || zret == Z_OK )
+      {
+        zret = deflate ( &myZStream, Z_FINISH );
+        if ( myZStream.avail_out >= 0 )
+        {
+          myUnderlyingStream.write ( ( char* ) myCompressedDataBuffer, MAX_BUFFER - myZStream.avail_out );
+          myZStream.next_out = myCompressedDataBuffer;
+          myZStream.avail_out = MAX_BUFFER;
+        }
+      }
+      deflateEnd ( &myZStream );
+    }
   }
 #endif
 }
 
 Engine::~Engine()
 {
-  if (myUnderlyingStream.good())
-	sync();
+  if ( myUnderlyingStream.good() )
+    sync();
 
-#ifndef	NO_COMPRESSION
-  delete [] myCompressedDataBuffer;
-  delete [] myUncompressedDataBuffer;
+#ifndef NO_COMPRESSION
+  if ( use_compression )
+  {
+    delete [] myCompressedDataBuffer;
+    delete [] myUncompressedDataBuffer;
+  }
 #endif
 }
 
 void Engine::writeBinary(const uint8* data, const uint32 size)
   THROWS (PersistException) {
-  if(myOperationalMode != modeWrite)
-	THROW("Cannot write to an input Engine");
+  if ( myOperationalMode != modeWrite )
+    THROW ( "Cannot write to an input Engine" );
 #ifdef NO_COMPRESSION
   myUnderlyingStream.write((const char *)data,size);
 #else
-  // Compress the data here and doit :)
-  uint32 written = 0;
-  while (written < size) {
-	// transfer as much information as we can into the input buffer.
-	if (myZStream.avail_in < MAX_BUFFER) {
-	  uint32 toAdd = size - written;
-	  if (toAdd > (MAX_BUFFER - myZStream.avail_in))
-	  toAdd = (MAX_BUFFER - myZStream.avail_in);
-	  memcpy(myZStream.next_in + myZStream.avail_in, data+written,toAdd);
-	  written += toAdd;
-	  myZStream.avail_in += toAdd;
-		}
-	if (myZStream.avail_in < MAX_BUFFER)
-	return; // We have not filled the buffer, so let's carry on streaming
-	// We have a full input buffer, so we compressit.
-	while (myZStream.avail_in > 0) {
-	  deflate(&myZStream,0);
-	  if (myZStream.avail_out == 0) {
-		// We filled the output buffer, let's stream it
-		myUnderlyingStream.write((char*)myCompressedDataBuffer,MAX_BUFFER);
-		myZStream.next_out = myCompressedDataBuffer;
-		myZStream.avail_out = MAX_BUFFER;
-	  }
-	  // Repeat whilst the input buffer isn't flushed
-		}
-	// Now we have flushed the input buffer we can reset it
-	myZStream.avail_in = 0;
-	myZStream.next_in = myUncompressedDataBuffer;
+  if (use_compression)
+  {
+    // Compress the data here and doit :)
+    uint32 written = 0;
+    while ( written < size )
+    {
+      // transfer as much information as we can into the input buffer.
+      if ( myZStream.avail_in < MAX_BUFFER )
+      {
+        uint32 toAdd = size - written;
+        if ( toAdd > ( MAX_BUFFER - myZStream.avail_in ) )
+          toAdd = ( MAX_BUFFER - myZStream.avail_in );
+        memcpy ( myZStream.next_in + myZStream.avail_in, data + written, toAdd );
+        written += toAdd;
+        myZStream.avail_in += toAdd;
+      }
+      if ( myZStream.avail_in < MAX_BUFFER )
+        return; // We have not filled the buffer, so let's carry on streaming
+      // We have a full input buffer, so we compressit.
+      while ( myZStream.avail_in > 0 )
+      {
+        deflate ( &myZStream, 0 );
+        if ( myZStream.avail_out == 0 )
+        {
+          // We filled the output buffer, let's stream it
+          myUnderlyingStream.write ( ( char* ) myCompressedDataBuffer, MAX_BUFFER );
+          myZStream.next_out = myCompressedDataBuffer;
+          myZStream.avail_out = MAX_BUFFER;
+        }
+        // Repeat whilst the input buffer isn't flushed
+      }
+      // Now we have flushed the input buffer we can reset it
+      myZStream.avail_in = 0;
+      myZStream.next_in = myUncompressedDataBuffer;
+    }
+  }
+  else
+  {
+    myUnderlyingStream.write ( ( const char * ) data, size );
   }
 #endif
 }
 
 void Engine::readBinary(uint8* data, uint32 size) THROWS (PersistException)
 {
-  if(myOperationalMode != modeRead)
-	THROW("Cannot read from an output Engine");
+  if ( myOperationalMode != modeRead )
+    THROW ( "Cannot read from an output Engine" );
 #ifdef NO_COMPRESSION
   myUnderlyingStream.read((char *)data,size);
 #else
-  uint32 read = 0;
-  while (read < size) {
-	// If we have any data left in the uncompressed buffer - use it
-	if (myLastUncompressedDataRead < myZStream.next_out) {
-	  uint32 toRead = size - read;
-	  if (toRead > (uint32)(myZStream.next_out - myLastUncompressedDataRead))
-	  toRead = (myZStream.next_out - myLastUncompressedDataRead);
-	  memcpy(data+read,myLastUncompressedDataRead,toRead);
-	  myLastUncompressedDataRead += toRead;
-	  read += toRead;
-		}
-	if (read == size)
-	return; // We have read all we need to
-	// Reset the stream for the next block of data
-	myLastUncompressedDataRead = myUncompressedDataBuffer;
-	myZStream.next_out = myUncompressedDataBuffer;
-	myZStream.avail_out = MAX_BUFFER;
-	// Next we have to deal such that, until we have a full output buffer,
-	// (Or we run out of input)
-	if (myUnderlyingStream.good()) {
-	  while (myUnderlyingStream.good() && myZStream.avail_out > 0) {
-		// Right then, if we have run out of input, fetch another chunk
-		if (myZStream.avail_in == 0) {
-		  myZStream.next_in = myCompressedDataBuffer;
-		  myUnderlyingStream.read((char*)myCompressedDataBuffer,MAX_BUFFER);
-		  myZStream.avail_in = myUnderlyingStream.gcount();
-				}
-		inflate(&myZStream,0);
-	  }
-		}
-	else {
-	  // Oh dear - we ran out of input on the buffer.
-	  // Maybe we can still inflate some
-	  inflate(&myZStream,0);
-	  if (myZStream.avail_out == MAX_BUFFER)
+  if ( use_compression )
+  {
+    uint32 read = 0;
+    while ( read < size )
+    {
+      // If we have any data left in the uncompressed buffer - use it
+      if ( myLastUncompressedDataRead < myZStream.next_out )
+      {
+        uint32 toRead = size - read;
+        if ( toRead > ( uint32 ) ( myZStream.next_out - myLastUncompressedDataRead ) )
+          toRead = ( myZStream.next_out - myLastUncompressedDataRead );
+        memcpy ( data + read, myLastUncompressedDataRead, toRead );
+        myLastUncompressedDataRead += toRead;
+        read += toRead;
+      }
+      if ( read == size )
+        return; // We have read all we need to
+      // Reset the stream for the next block of data
+      myLastUncompressedDataRead = myUncompressedDataBuffer;
+      myZStream.next_out = myUncompressedDataBuffer;
+      myZStream.avail_out = MAX_BUFFER;
+      // Next we have to deal such that, until we have a full output buffer,
+      // (Or we run out of input)
+      if ( myUnderlyingStream.good() )
+      {
+        while ( myUnderlyingStream.good() && myZStream.avail_out > 0 )
+        {
+          // Right then, if we have run out of input, fetch another chunk
+          if ( myZStream.avail_in == 0 )
+          {
+            myZStream.next_in = myCompressedDataBuffer;
+            myUnderlyingStream.read ( ( char* ) myCompressedDataBuffer, MAX_BUFFER );
+            myZStream.avail_in = myUnderlyingStream.gcount();
+          }
+          inflate ( &myZStream, 0 );
+        }
+      }
+      else
+      {
+        // Oh dear - we ran out of input on the buffer.
+        // Maybe we can still inflate some
+        inflate ( &myZStream, 0 );
+        if ( myZStream.avail_out == MAX_BUFFER )
 //        THROW (PersistException(String("Oh dear - ran out of input")));
-		THROW (Exception(String("Oh dear - ran out of input")));
-		}
+          THROW ( Exception ( String ( "Oh dear - ran out of input" ) ) );
+      }
+    }
+  }
+  else
+  {
+    myUnderlyingStream.read ( ( char * ) data, size );
   }
 #endif
 }
