@@ -156,18 +156,22 @@ IPV4Address &IPV4Address::operator=(struct in_addr addr)
 
 IPV4Address &IPV4Address::operator=(unsigned long addr)
 {
-	void *vp = (void *)&addr;
-	struct in_addr *aptr = (struct in_addr *)vp;
+	union {
+		uint32 addr;
+		struct in_addr in4;
+	} aptr;
+
+	aptr.addr = addr;
 
 	if ( validator )
-		(*validator)(*aptr);
+		(*validator)(aptr.in4);
 
 	if(ipaddr)
 		delete[] ipaddr;
 
 	addr_count = 1;
 	ipaddr = new struct in_addr[1];
-	memcpy(ipaddr, &addr, sizeof(struct in_addr));
+	memcpy(ipaddr, &aptr.in4, sizeof(struct in_addr));
 	if(hostname)
 		delString(hostname);
 	hostname = NULL;
