@@ -65,8 +65,8 @@ LinkedSingle *LinkedSingle::getLast(void)
 
 void LinkedSingle::insert(LinkedSingle& obj)
 {
-	nextObject = obj.nextObject;
-	obj.nextObject = this;
+  obj.nextObject = nextObject;
+  nextObject = &obj;
 }
 
 LinkedSingle &LinkedSingle::operator+=(LinkedSingle &obj)
@@ -84,14 +84,32 @@ void LinkedDouble::enterLock() {}
 
 void LinkedDouble::leaveLock() {}
 
+LinkedDouble *LinkedDouble::firstObject()
+{
+  LinkedDouble *node = this;
+
+  while(node->prevObject)
+    node = node->prevObject;
+
+  return node;
+}
+
+LinkedDouble *LinkedDouble::lastObject()
+{
+  LinkedDouble *node = this;
+
+  while(node->nextObject)
+    node = node->nextObject;
+
+  return node;
+}
+
 LinkedDouble *LinkedDouble::getFirst(void)
 {
 	LinkedDouble *node;
 
   enterLock();
-  node = this;
-	while(node->prevObject)
-		node = node->prevObject;
+  node = firstObject();
   leaveLock();
 
 	return node;
@@ -102,9 +120,7 @@ LinkedDouble *LinkedDouble::getLast(void)
 	LinkedDouble *node;
 
   enterLock();
-  node = this;
-	while(node->nextObject)
-		node = node->nextObject;
+  node = lastObject();
   leaveLock();
 
 	return node;
@@ -125,7 +141,7 @@ void LinkedDouble::insert(LinkedDouble& obj, InsertMode position)
   switch ( position )
   {
     case modeAtFirst :
-      node = getFirst();
+      node = firstObject();
       obj.nextObject = node;
       node->prevObject = &obj;
       break;
@@ -147,17 +163,14 @@ void LinkedDouble::insert(LinkedDouble& obj, InsertMode position)
       break;
 
     case modeAtLast :
-      node = getLast();
+    default :
+      node = lastObject();
       obj.nextObject = node->nextObject;
       obj.prevObject = node;
       node->nextObject = &obj;
       if(obj.nextObject)
         obj.nextObject->prevObject = &obj;
       break;
-
-    default :
-      insert(obj);
-      break;
   }
   leaveLock();
 }
