@@ -1587,11 +1587,11 @@ Socket::Error UDPSocket::getInterfaceIndex(const char *DeviceName,int& Interface
   struct ip_mreqn  mreqn;
   struct ifreq     m_ifreq;
   int              i;
-  sockaddr*        sa = (sockaddr*) &peer.ipv4;
-
+  sockaddr_in*        in4 = (sockaddr_in*) &peer.ipv4;
   InterfaceIndex = -1;
 
-  mreqn.imr_multiaddr = *(struct in_addr *) &(sa->sa_data[2]);
+  memset(&mreqn, 0, sizeof(mreqn));
+  memcpy(&mreqn.imr_multiaddr.s_addr, &in4->sin_addr, sizeof(mreqn.imr_multiaddr.s_addr));
 
   for (i = 0; i < IFNAMSIZ && DeviceName[i]; ++i)
 	m_ifreq.ifr_name[i] = DeviceName[i];
@@ -2269,7 +2269,7 @@ Socket(accept(server.so, NULL, NULL))
 	Socket::state = CONNECTED;
 	socklen_t alen = sizeof(peer);
 
-	getpeername(so, (struct sockaddr *)&peer, &alen);	
+	getpeername(so, (struct sockaddr *)&peer, &alen);
 
 	switch(family) {
 #ifdef	CCXX_IPV6
@@ -2510,6 +2510,20 @@ bool DCCPSocket::onAccept(const IPV4Host &ia, tpport_t port)
 	return true;
 }
 
+IPV4Host DCCPSocket::getIPV4Sender(tpport_t *port) const
+{
+        if(port)
+                *port = ntohs(peer.ipv4.sin_port);
+        return IPV4Host(peer.ipv4.sin_addr);
+}
+
+#ifdef	CCXX_IPV6
+IPV6Host DCCPSocket::getIPV6Sender(tpport_t *port) const
+{
+	return IPV6Host(peer.ipv6.sin6_addr);
+}
+#endif
+
 DCCPSocket::~DCCPSocket()
 {
 	endSocket();
@@ -2776,7 +2790,7 @@ bool DCCPSocket::setCCID(uint8 ccid)
 	 */
 	ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_AVAILABLE_CCIDS, (char *)&ccids, &len);
 	if (ret < 0) {
-		cout << "Can not determine available CCIDs" << endl;
+		error(errInput,(char *)"Can not determine available CCIDs",socket_errno);
 		return false;
 	}
 
@@ -2788,12 +2802,12 @@ bool DCCPSocket::setCCID(uint8 ccid)
 	}
 
 	if (!ccid_supported) {
-		cout << "CCID specified is not supported" << endl;
+		error(errInput,(char *)"CCID specified is not supported",socket_errno);
 		return false;
 	}
 
 	if (setsockopt(so, SOL_DCCP, DCCP_SOCKOPT_CCID, (char *)&ccid, sizeof (ccid)) < 0) {
-		cout << "Can not set CCID" << endl;
+		error(errInput,(char *)"Can not set CCID",socket_errno);
 		return false;
 	}
 
@@ -2808,7 +2822,7 @@ int DCCPSocket::getTxCCID()
     ccidlen = sizeof(ccid);
     ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_TX_CCID, (char *)&ccid, &ccidlen);
     if (ret < 0) {
-        cout << "Can not determine get current TX CCID value" << endl;
+	error(errInput,(char *)"Can not determine get current TX CCID value",socket_errno);
         return -1;
     }
     return ccid;
@@ -2822,12 +2836,30 @@ int DCCPSocket::getRxCCID()
     ccidlen = sizeof(ccid);
     ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_RX_CCID, (char *)&ccid, &ccidlen);
     if (ret < 0) {
-        cout << "Can not determine get current RX CCID value" << endl;
+	error(errInput,(char *)"Can not determine get current DX CCID value",socket_errno);
         return -1;
     }
     return ccid;
 }
 
+#ifndef WIN32
+#include <sys/ioctl.h>
+#endif
+size_t  DCCPSocket::available()
+{
+	size_t readsize;
+#ifndef WIN32
+	 if (ioctl (so, FIONREAD, &readsize) < 0) {
+		 error(errInput,(char *)"Error on retrieve the FIONREAD option.",socket_errno);
+	 }
+#else
+	if (ioctlsocket(so, FIOREAD, &readsize)){
+		error(errInput,(char *)"Error on retrieve the FIONREAD option.",socket_errno);
+	}
+#endif
+	return readsize;
+}
+
 TCPStream::TCPStream(TCPSocket &server, bool throwflag, timeout_t to) :
 	streambuf(), Socket(accept(server.getSocket(), NULL, NULL)),
 #ifdef	HAVE_OLD_IOSTREAM
