@@ -1,4 +1,5 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -426,7 +427,7 @@ void String::copy(const String &original)
 //	ptr = original.getText();
 	content.bigstring.length = original.getLength();
 	content.bigstring.size = setSize(original.getLength() + 1);
-	content.bigstring.text = getSpace(content.bigstring.size);
+	content.bigstring.text = getSpace(original.getLength() + 1);
 	content.ministring.big = true;
 	memmove(content.bigstring.text, original.getText(), original.getLength() + 1);
 }
