@@ -6,7 +6,7 @@ using namespace ost;
 #endif
 
 // This is a little regression test
-// 
+//
 
 class ThreadTest: public Thread
 {
@@ -19,8 +19,7 @@ volatile int n = 0;
 
 bool WaitNValue(int value)
 {
-	for(int i=0;; ++i)
-	{
+	for(int i=0;; ++i) {
 		if (n == value)
 			break;
 		if (i >= 100)
@@ -32,8 +31,7 @@ bool WaitNValue(int value)
 
 bool WaitChangeNValue(int value)
 {
-	for(int i=0;; ++i)
-	{
+	for(int i=0;; ++i) {
 		if (n != value)
 			break;
 		if (i >= 100)
@@ -56,8 +54,7 @@ void ThreadTest::run()
 	if (!WaitNValue(2)) return;
 
 	// increment infinitely
-	for(;;)
-	{
+	for(;;) {
 		yield();
 		n = n+1;
 	}
@@ -69,8 +66,7 @@ bool TestChange(bool shouldChange)
 		printf("- thread should change n...");
 	else
 		printf("- thread should not change n...");
-	if (WaitChangeNValue(n) == shouldChange)
-	{
+	if (WaitChangeNValue(n) == shouldChange) {
 		printf("ok\n");
 		return true;
 	}
@@ -108,7 +104,7 @@ int main(int argc, char* argv[])
 	n = 2;
 	TEST_CHANGE(true);
 	TEST_CHANGE(true);
-	
+
 	// suspend thread, variable should not change
 	printf("\nTesting suspend & resume\n\n");
 	test.suspend();
@@ -125,7 +121,7 @@ int main(int argc, char* argv[])
 	test.suspend();
 	TEST_CHANGE(false);
 	TEST_CHANGE(false);
-	
+
 	test.resume();
 	TEST_CHANGE(false);
 	TEST_CHANGE(false);
@@ -137,7 +133,7 @@ int main(int argc, char* argv[])
 	test.resume();
 	TEST_CHANGE(true);
 	TEST_CHANGE(true);
-		
+
 	// suspend thread, variable should not change
 	printf("\nTesting resuspend\n\n");
 	test.suspend();
