@@ -89,8 +89,8 @@ void checkStringOverflow(char* s,unsigned int len)
 
 int main()
 {
-	checkStringOverflow("",0);
-	checkStringOverflow("aaa",3);
+	checkStringOverflow((char *)"",0);
+	checkStringOverflow((char *)"aaa",3);
 	if (!errorOccurred)
 		printf("All seem ok\n");
 	return 0;
